Kernel command line parsing and manipulation.
This module provides utilities for parsing and generating kernel command line arguments, with specific support for composefs parameters. It handles the kernel’s simple quoting mechanism and provides functions to extract and create composefs= arguments with optional insecure mode indicators.
Structs
- Digest
Descriptor - Parsed format descriptor from a
composefs.digest=value.
Enums
- Composefs
Cmdline - A composefs kernel argument identifying which EROFS image to mount at boot.
Constants
- KARG_
COMPOSEFS_ DIGEST - Self-describing kernel argument:
composefs.digest=<version>-<hash>-<lg>:<hex>. - KARG_V2
- Legacy kernel argument for V2 EROFS:
composefs=<hex_digest>.
Functions
- get_
cmdline_ value - Gets the value of an entry from the kernel cmdline.
- make_
cmdline_ composefs - Creates a composefs kernel command line argument string.
- parse_
digest_ value - Parse a
composefs.digest=value likev1-sha256-12:<hex>orv2-sha512-12:<hex>. - split_
cmdline - Perform kernel command line splitting.